
/*
 * Copyright (C) 2004-2005 Maximilian Schwerin
 *
 * This file is part of oxine a free media player.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: mediamarks_favorites.h 2340 2007-06-27 09:47:43Z mschwerin $
 *
 */

#ifndef HAVE_MEDIAMARKS_FAVORITES
#define HAVE_MEDIAMARKS_FAVORITES

#include "filelist.h"

void favorites_add_directory (filelist_t * favorites_filelist,
                              const char *title, const char *mrl);

#endif /* HAVE_MEDIAMARKS_FAVORITES */
